@@ -1,4 +1,4 @@
-# $Id: Defines.pm 20440 2006-05-19 13:46:40Z wsnyder $
+# $Id: Defines.pm 26604 2006-10-17 20:52:48Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -22,7 +22,7 @@ use strict;
 use Carp;
 use vars qw($VERSION);
 
-$VERSION = '1.420';
+$VERSION = '1.421';
 
 ######################################################################
 # CONSTRUCTOR
@@ -107,6 +107,8 @@ sub _body {
     my $pack = shift;
     my $fl = shift;
     
+    $fl->print("{\n    no warnings 'portable';\n") if $fl->{Perl};
+
     my $firstauto = 1;
     foreach my $defref ($pack->defines_sorted) {
 	if ($firstauto && !$defref->{is_manual}) {
@@ -122,9 +124,11 @@ sub _body {
 	    next;  # Skip for Perl/C++, not much point as we have structs
 	}
 	$value = $fl->sprint_hex_value_add0 ($value,$defref->{bits}) if (defined $defref->{bits});
-	if ($fl->{Perl} && ($defref->{bits}||0) > 32) {
-	    $fl->print ("#");
-	    $comment .= " (TOO LARGE FOR PERL)";
+	if ($fl->{Perl}) {
+	    if (($defref->{bits}||0) > 64) {
+		$fl->print ("#");
+		$comment .= " (TOO LARGE FOR PERL)";
+	    }
 	}
 	if (($defref->{is_verilog} && $fl->{Verilog})
 	    || ($defref->{is_perl} && $fl->{Perl})
@@ -133,6 +137,8 @@ sub _body {
 			 ($pack->{comments}?$comment:""));
 	}
     }
+
+    $fl->print("}\n") if $fl->{Perl};
 }
 
 ######################################################################
@@ -175,6 +181,10 @@ definitions in a language appropriate way.
 
 =head1 DISTRIBUTION
 
+Vregs is part of the L<http://www.veripool.com/> free Verilog software tool
+suite.  The latest version is available from CPAN and from
+L<http://www.veripool.com/vregs.html>.  /www.veripool.com/>.
+
 Copyright 2001-2006 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
