@@ -1,4 +1,4 @@
-# $Id: TableExtract.pm 20440 2006-05-19 13:46:40Z wsnyder $
+# $Id: TableExtract.pm 26604 2006-10-17 20:52:48Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -16,7 +16,7 @@
 package SystemC::Vregs::TableExtract;
 
 use base qw(HTML::TableExtract);
-$VERSION = '1.420';
+$VERSION = '1.421';
 
 use strict;
 use vars qw($Debug %Find_Start_Headers %Find_Headers);
@@ -271,7 +271,9 @@ It is designed to be used by SystemC::Vregs only.
 
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN and from L<http://www.veripool.com/>.
+Vregs is part of the L<http://www.veripool.com/> free Verilog software tool
+suite.  The latest version is available from CPAN and from
+L<http://www.veripool.com/vregs.html>.  /www.veripool.com/>.
 
 Copyright 2001-2006 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
